@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.cpp 2271 2006-12-16 20:15:22Z svn $
+ * $Id: PostDataChecker.cpp 2272 2006-12-17 10:21:48Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,14 +36,14 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2271 2006-12-16 20:15:22Z svn $");
+SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2272 2006-12-17 10:21:48Z svn $");
 
 const char PostDataChecker::HTML_EXT[]      = "htm";
 
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_off_t file_size,
+void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_uint64_t file_size,
                                      apr_time_t  mtime, const char **file_name,
                                      const char **file_mime,
                                      const char *file_digest,
